@@ -311,18 +311,15 @@ In case the service has been recently started please wait 5 minutes for it to be
         if circuit is None and circuits is None:
             print("An quantum circuit to be executed or a list of quantum circuits to be executed must be specified.")
             return
-        if circuit and circuits:
+        if circuit is not None and circuits is not None:
             print("You can use either 'circuit' or 'circuits' as input arguments but not both at the same time.")
             return
-        if circuit and not isinstance(circuit, QuantumCircuit):
+        if circuit is not None and not isinstance(circuit, QuantumCircuit):
             print("The circuit must be an instance of QuantumCircuit.")
             return
-        if circuits and not isinstance(circuits, list):
+        if not isinstance(circuits, list) or not all(isinstance(circ, QuantumCircuit) for circ in circuits):
             print("The circuits must be a list of QuantumCircuit instances.")
             return
-        if circuits is not None and len(circuits) == 0:
-            print("The circuits list is empty.")
-            return
         if shots is None:
             print("Please specify the number of shots.")
             return
@@ -330,7 +327,7 @@ In case the service has been recently started please wait 5 minutes for it to be
             print("The number of shots must be specified as an integer number.")
             return
         try:
-            if circuit:
+            if circuit is not None:
                 job_data = {
                     "BackendName": backend,
                     "Circuit": serialize_circuit(circuit),
@@ -338,7 +335,7 @@ In case the service has been recently started please wait 5 minutes for it to be
                     "Shots": shots,
                     "Comments": comments,
                 }
-            elif circuit:
+            elif circuits is not None:
                 job_data = {
                     "BackendName": backend,
                     "Circuit": None,
